Index: src/gpu/GrPipelineBuilder.h |
diff --git a/src/gpu/GrPipelineBuilder.h b/src/gpu/GrPipelineBuilder.h |
index 447a981f3a854e5205ee14fa7d1c700c3fb346bb..09b4f91e7304760e8b386c579bf8af1aeeb25ba7 100644 |
--- a/src/gpu/GrPipelineBuilder.h |
+++ b/src/gpu/GrPipelineBuilder.h |
@@ -177,10 +177,10 @@ public: |
} |
/** |
* Checks whether the xp will need a copy of the destination to correctly blend. |
*/ |
- bool willXPNeedDstCopy(const GrCaps& caps, const GrProcOptInfo& colorPOI, |
- const GrProcOptInfo& coveragePOI) const; |
+ bool willXPNeedDstTexture(const GrCaps& caps, const GrProcOptInfo& colorPOI, |
+ const GrProcOptInfo& coveragePOI) const; |
/// @} |
@@ -177,10 +177,10 @@ public: |
} |
/** |
- * Checks whether the xp will need a copy of the destination to correctly blend. |
+ * Checks whether the xp will need destination in a texture to correctly blend. |
*/ |